==> spip_3.0.8.orig.tar.xz: spip-3.0.8.orig/plugins-dist/mots/lang/mots_ast.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/mots?lang_cible=ast
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_conseil_selection_mot_cle' => '<b>Grupu importante:</b> s\'encamienta fonderamente escoyer una pallabra-clave pa esti grupu.',
	'avis_doublon_mot_cle' => 'Yá esiste una pallabra con esti títulu. ¿Tas seguru de que quies crear la mesma?',

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'los y les alministradores del sitiu',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'Los y les redactores',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'los visitantes del sitiu públicu cuando pongan un mensaxe nun foru',

	// C
	'creer_et_associer_un_mot' => 'Créér et associer un mot-clé', # MODIF

	// I
	'icone_creation_groupe_mots' => 'Crear un nuevu grupu de pallabres',
	'icone_creation_mots_cles' => 'Crear una nueva pallabra-clave',
	'icone_modif_groupe_mots' => 'Cambear esti grupu de pallabres',
	'icone_modifier_mot' => 'Iguar esta pallabra',
	'icone_mots_cles' => 'Pallabres-clave',
	'icone_supprimer_groupe_mots' => 'Desaniciar esti grupu',
	'icone_voir_groupe_mots' => 'Voir ce groupe de mots', # NEW
	'icone_voir_tous_mots_cles' => 'Ver toles pallabres-clave',
	'info_1_groupe_mots' => '1 groupe de mots', # NEW
	'info_articles_lies_mot' => 'Los artículos enllazaos con esta pallabra-clave',
	'info_aucun_groupe_mots' => 'Aucun groupe de mots', # NEW
	'info_aucun_mot_cle' => 'Denguna pallabra-clave',
	'info_changer_nom_groupe' => 'Cambear el nome d\'esti grupu:',
	'info_creation_mots_cles' => 'Crear ya iguar les pallabres clave del sitiu',
	'info_dans_groupe' => 'Nel grupu:',
	'info_delet_mots_cles' => 'Pedisti desaniciar la pallabra-clave
<b>@titre_mot@</b> (@type_mot@). Como esta pallabra ta enllazada
con <b>@texte_lie@</b> debes confirmar esta decisión:', # MODIF
	'info_groupe_important' => 'Grupu importante',
	'info_modifier_mot' => 'Modificar la pallabra-clave:',
	'info_mots_cles' => 'Les pallabres-clave',
	'info_mots_cles_association' => 'Les pallabres-clave d\'esti grupu puen asociase:',
	'info_nb_groupe_mots' => '@nb@ groupes de mots', # NEW
	'info_oui_suppression_mot_cle' => 'quiero desaniciar definitivamente esta pallabra-clave.',
	'info_question_mots_cles' => '¿Quies utilizar les pallabres-clave nesti sitiu?',
	'info_qui_attribue_mot_cle' => 'Les pallabres d\'esti grupu puen conseñase por:',
	'info_remplacer_mot' => 'Trocar "@titre@"',
	'info_retirer_mot' => 'Retirar esta pallabra',
	'info_retirer_mots' => 'Retirar toles pallabres',
	'info_rubriques_liees_mot' => 'Les estayes lligáes con esta pallabra-clave',
	'info_selection_un_seul_mot_cle' => 'Nun se pue seleicionar más que <b>una sola pallabra-clave</b> a la vez nesti grupu.', # MODIF
	'info_supprimer_mot' => 'desaniciar esta pallabra',
	'info_titre_mot_cle' => 'Nome o títulu de la pallabra clave',
	'info_un_mot' => 'Una sola pallabra a la vez',
	'item_ajout_mots_cles' => 'Autorizar l\'amestura de pallabres-clave nos foros',
	'item_non_ajout_mots_cles' => 'Torgar l\'usu de les pallabres-clave nos foros',
	'item_non_utiliser_config_groupe_mots_cles' => 'Nun utilizar la configuración avanzada de los grupos de pallabres-clave',
	'item_non_utiliser_mots_cles' => 'Nun utilizar les pallabres-clave',
	'item_utiliser_config_groupe_mots_cles' => 'Utilizar la configuración avanzada de los grupos de pallabres-clave',
	'item_utiliser_mots_cles' => 'Utilizar les pallabres-clave',

	// L
	'lien_ajouter_mot' => 'Amestar esta pallabra-clave',
	'logo_groupe' => 'LOGO D\'ESTI GRUPU',
	'logo_mot_cle' => 'LOGO DE LA PALLABRA-CLAVE',

	// T
	'texte_config_groupe_mots_cles' => '¿Quies activar la configuración avanzada de les pallabres-clave,
   conseñando por exemplu que pue seleicionase una pallabra única
   por grupu, que un grupu ye importante...?', # MODIF
	'texte_mots_cles' => 'Les pallabres-clave permiten crear enllaces temáticos ente artículos
  independientemente del so allugamientu nes estayes. D\'esti mou pues
  arriquecer la ñavegacion pol sitiu, y utilizar estes propiedáes
  pa personalizar la presentación de los artículos nes tos cadarmes.',
	'texte_mots_cles_dans_forum' => '¿Quiés permitir l\'usu de pallabres-clave seleicionables polos visitantes nos foros del sitiu públicu? (Atención: esta opción ye relativamente abegoso utilizala correutamente.)',
	'texte_nouveau_mot' => 'Pallabra nueva',
	'titre_config_groupe_mots_cles' => 'Configuración de los grupos de pallabres-clave',
	'titre_gauche_mots_edit' => 'PALLABRA NÚMBERU:',
	'titre_groupe_mots' => 'Groupe de mots-clés', # NEW
	'titre_groupe_mots_numero' => 'GROUPE DE MOTS NUMÉRO :', # NEW
	'titre_groupes_mots' => 'Groupes de mots-clés', # NEW
	'titre_mots_cles_dans_forum' => 'Pallabres-clave nos foros del sitiu públicu',
	'titre_mots_tous' => 'Les pallabres-clave',
	'titre_nouveau_groupe' => 'Grupu nuevu',
	'titre_objets_lies_mot' => 'Liés à ce mot-clé :', # NEW
	'titre_page_mots_tous' => 'Pallabres-clave'
);

?>

==> spip_3.0.11.orig.tar.xz: spip-3.0.11.orig/plugins-dist/mots/lang/mots_ast.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/mots?lang_cible=ast
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_conseil_selection_mot_cle' => '<b>Grupu importante:</b> s\'encamienta fonderamente escoyer una pallabra-clave pa esti grupu.',
	'avis_doublon_mot_cle' => 'Yá esiste una pallabra con esti títulu. ¿Tas seguru de que quies crear la mesma?', # MODIF

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'los y les alministradores del sitiu',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'Los y les redactores',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'los visitantes del sitiu públicu cuando pongan un mensaxe nun foru',

	// C
	'creer_et_associer_un_mot' => 'Créér et associer un mot-clé', # MODIF

	// I
	'icone_creation_groupe_mots' => 'Crear un nuevu grupu de pallabres',
	'icone_creation_mots_cles' => 'Crear una nueva pallabra-clave',
	'icone_modif_groupe_mots' => 'Cambear esti grupu de pallabres',
	'icone_modifier_mot' => 'Iguar esta pallabra',
	'icone_mots_cles' => 'Pallabres-clave',
	'icone_supprimer_groupe_mots' => 'Desaniciar esti grupu',
	'icone_voir_groupe_mots' => 'Voir ce groupe de mots', # NEW
	'icone_voir_tous_mots_cles' => 'Ver toles pallabres-clave',
	'info_1_groupe_mots' => '1 groupe de mots', # NEW
	'info_articles_lies_mot' => 'Los artículos enllazaos con esta pallabra-clave',
	'info_aucun_groupe_mots' => 'Aucun groupe de mots', # NEW
	'info_aucun_mot_cle' => 'Denguna pallabra-clave',
	'info_changer_nom_groupe' => 'Cambear el nome d\'esti grupu:',
	'info_creation_mots_cles' => 'Crear ya iguar les pallabres clave del sitiu',
	'info_dans_groupe' => 'Nel grupu:',
	'info_delet_mots_cles' => 'Pedisti desaniciar la pallabra-clave
<b>@titre_mot@</b> (@type_mot@). Como esta pallabra ta enllazada
con <b>@texte_lie@</b> debes confirmar esta decisión:', # MODIF
	'info_groupe_important' => 'Grupu importante',
	'info_modifier_mot' => 'Modificar la pallabra-clave:',
	'info_mots_cles' => 'Les pallabres-clave',
	'info_mots_cles_association' => 'Les pallabres-clave d\'esti grupu puen asociase:',
	'info_nb_groupe_mots' => '@nb@ groupes de mots', # NEW
	'info_oui_suppression_mot_cle' => 'quiero desaniciar definitivamente esta pallabra-clave.',
	'info_question_mots_cles' => '¿Quies utilizar les pallabres-clave nesti sitiu?',
	'info_qui_attribue_mot_cle' => 'Les pallabres d\'esti grupu puen conseñase por:',
	'info_remplacer_mot' => 'Trocar "@titre@"',
	'info_retirer_mot' => 'Retirar esta pallabra',
	'info_retirer_mots' => 'Retirar toles pallabres',
	'info_rubriques_liees_mot' => 'Les estayes lligáes con esta pallabra-clave',
	'info_selection_un_seul_mot_cle' => 'Nun se pue seleicionar más que <b>una sola pallabra-clave</b> a la vez nesti grupu.', # MODIF
	'info_supprimer_mot' => 'desaniciar esta pallabra',
	'info_titre_mot_cle' => 'Nome o títulu de la pallabra clave',
	'info_un_mot' => 'Una sola pallabra a la vez',
	'item_ajout_mots_cles' => 'Autorizar l\'amestura de pallabres-clave nos foros',
	'item_non_ajout_mots_cles' => 'Torgar l\'usu de les pallabres-clave nos foros',
	'item_non_utiliser_config_groupe_mots_cles' => 'Nun utilizar la configuración avanzada de los grupos de pallabres-clave',
	'item_non_utiliser_mots_cles' => 'Nun utilizar les pallabres-clave',
	'item_utiliser_config_groupe_mots_cles' => 'Utilizar la configuración avanzada de los grupos de pallabres-clave',
	'item_utiliser_mots_cles' => 'Utilizar les pallabres-clave',

	// L
	'lien_ajouter_mot' => 'Amestar esta pallabra-clave',
	'logo_groupe' => 'LOGO D\'ESTI GRUPU',
	'logo_mot_cle' => 'LOGO DE LA PALLABRA-CLAVE',

	// T
	'texte_config_groupe_mots_cles' => '¿Quies activar la configuración avanzada de les pallabres-clave,
   conseñando por exemplu que pue seleicionase una pallabra única
   por grupu, que un grupu ye importante...?', # MODIF
	'texte_mots_cles' => 'Les pallabres-clave permiten crear enllaces temáticos ente artículos
  independientemente del so allugamientu nes estayes. D\'esti mou pues
  arriquecer la ñavegacion pol sitiu, y utilizar estes propiedáes
  pa personalizar la presentación de los artículos nes tos cadarmes.',
	'texte_mots_cles_dans_forum' => '¿Quiés permitir l\'usu de pallabres-clave seleicionables polos visitantes nos foros del sitiu públicu? (Atención: esta opción ye relativamente abegoso utilizala correutamente.)',
	'texte_nouveau_mot' => 'Pallabra nueva',
	'titre_config_groupe_mots_cles' => 'Configuración de los grupos de pallabres-clave',
	'titre_gauche_mots_edit' => 'PALLABRA NÚMBERU:',
	'titre_groupe_mots' => 'Groupe de mots-clés', # NEW
	'titre_groupe_mots_numero' => 'GROUPE DE MOTS NUMÉRO :', # NEW
	'titre_groupes_mots' => 'Groupes de mots-clés', # NEW
	'titre_mots_cles_dans_forum' => 'Pallabres-clave nos foros del sitiu públicu',
	'titre_mots_tous' => 'Les pallabres-clave',
	'titre_nouveau_groupe' => 'Grupu nuevu',
	'titre_objets_lies_mot' => 'Liés à ce mot-clé :', # NEW
	'titre_page_mots_tous' => 'Pallabres-clave'
);

?>
